@@ -66,9 +66,8 @@
 	  pfile
 	  (if (string=? (list-ref package-name 0) "unknown")
 	      (search-directories (list-ref package-name 1))
-	      (begin (display (string-append "upmf: package file not found for package: "
-					     package-string))
-		     (newline)(quit)))))))
+	      (errormsg (string-append (_ "Package file not found for package: ")
+				       package-string) 'fatal))))))
 
 ;; Find package NEEDLE
 ;; NEEDLE can be the name with or without the section.
